function createSounds()

	FBAR = [900, 1200, 1500];
	DELT = linspace(-600, 600, 10);

	for fbar = FBAR
		for delta = DELT
			singleSweep(fbar, delta);
			if abs(delta) < 350
				sweepTrain(fbar, delta);
			end
		end
	end


end



function singleSweep(fbar, delta)

    fs        = 48000; % Herz
    durations = [0.005, 0.04, 0.005]; % seconds

	f0 = fbar - 0.5 * delta;
	f1 = fbar + 0.5 * delta;
   
    N = durations * fs;
    stim = zeros([1, sum(N)]);
    
	fsweep = 1 ./ linspace(1 / f0, 1 / f1, N(2));
    f = [f0 * ones([1, N(1)]), fsweep, f1 * ones([1, N(3)])];
    phase = 2 * pi * cumsum(f) / fs;
    stim = stim + (1 / length(f0)) * sin(phase);

    N = durations(1) * fs;
    
    hamm = hamming(2 * N);
    modd = ones(size(stim));

    modd(1:N)                        = hamm(1:N);
    modd((length(stim) - N + 1):end) = hamm((N+1):end);

    stim = [zeros([1, 0.05*fs]), stim .* modd, zeros([1, 0.05*fs])];

    c = clock();
    audiowrite(sprintf('sweep_fbar%dHz_delta%dHz.wav', fbar, round(delta)), stim, fs);

    %sound(stim, fs);
    %pause(sum(durations) + 0.01);

end



function sweepTrain(fbar, delta)

    fs        = 48000; % Herz
    durations = [0.005, 0.04, 0.005]; % seconds
    reps      = 5; % Number of repetitions

	f0 = fbar - 0.5 * delta;
	f1 = fbar + 0.5 * delta;
   
    N = durations * fs;
    stim = zeros([1, sum(N)]);
    
    fsweep = 1 ./ linspace(1 / f0, 1 / f1, N(2));
    f = [];
    for i = 1:reps
        f = [f, f0 * ones([1, N(1)]), fsweep, f1 * ones([1, N(3)])];
    end

    phase = 2 * pi * cumsum(f) / fs;
    stim = (1 / length(f0)) * sin(phase);

    N = durations(1) * fs;
    
    hamm = hamming(2 * N);
    modd = ones(size(stim));

    modd(1:N)                        = hamm(1:N);
    modd((length(stim) - N + 1):end) = hamm((N+1):end);

    stim = [zeros([1, 0.05*fs]), stim .* modd, zeros([1, 0.05*fs])];

    c = clock();
    audiowrite(sprintf('train_fbar%dHz_delta%dHz.wav', fbar, round(delta)), stim, fs);

    %sound(stim, fs);
    %pause(sum(durations) + 0.01);

end
